summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorChristian Geier <geier@lostpackets.de>2023-06-24 00:05:53 +0200
committerChristian Geier <geier@lostpackets.de>2023-10-26 09:20:23 +0200
commitc182b1c55ed92c5e3e15eb0338afe0bdeadad8ff (patch)
tree6325712a05699bb5e87b345d0e65897f99cbb68f
parent9602e95e5e82a61878d868c3ddbd85db096442d9 (diff)
ikhal: switch from 256 to 2**24 colors
-rw-r--r--khal/ui/__init__.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/khal/ui/__init__.py b/khal/ui/__init__.py
index ea3919d4..27e6ee4e 100644
--- a/khal/ui/__init__.py
+++ b/khal/ui/__init__.py
@@ -1387,9 +1387,9 @@ def start_pane(pane, callback, program_info='', quit_keys=None):
loop.set_alarm_in(60, check_for_updates, pane)
loop.set_alarm_in(60, check_for_updates, pane)
# Make urwid use 256 color mode.
loop.screen.set_terminal_properties(
- colors=256, bright_is_bold=pane._conf['view']['bold_for_light_color'])
+ colors=2**24, bright_is_bold=pane._conf['view']['bold_for_light_color'])
def ctrl_c(signum, f):
raise urwid.ExitMainLoop()
@@ -1387,9 +1387,9 @@ def start_pane(pane, callback, program_info='', quit_keys=None):
loop.set_alarm_in(60, check_for_updates, pane)
loop.set_alarm_in(60, check_for_updates, pane)
- # Make urwid use 256 color mode.
+ # Make urwid use 2**24 color mode.
loop.screen.set_terminal_properties(